@@ -1,17 +1,29 @@
-
-
-
+use std::path::PathBuf;
 use super::*;
 
-
 /// An error message.
 #[derive(Clone, Debug, PartialEq, Eq, Hash)]
 pub struct Error {
 
 	pub(crate) next_maybe: Option<Rc<Error>>,
+	pub(crate) path_maybe: Option<PathBuf>,
 	pub(crate) span_maybe: Option<Span>,
-	pub(crate) description: String,
 	pub(crate) level: Level,
+	pub(crate) description: String,
+
+}
+
+impl Default for Error {
+
+	fn default() -> Self {
+		
+		let level = Level::Note;
+		let description = "";
+		let span_maybe = None;
+
+		Error::new(span_maybe, level, description)
+	
+	}
 
 }
 
@@ -53,14 +65,22 @@ impl Error {
 		&self.span_maybe
 
 	}
+
+	/// `self.level`
+	pub fn level(&self) -> Level {
+
+		self.level
+
+	}
 	
-	/// A constructor for `Message`.
+	/// A constructor for `Error`.
 	pub fn new(span_maybe: Option<Span>, level: Level, description: &str) -> Self {
 
-		let description = description.to_string();
 		let next_maybe = None;
+		let path_maybe = None;
+		let description = description.to_string();
 
-		Self { next_maybe, span_maybe, description, level }		
+		Self { next_maybe, span_maybe, level, description, path_maybe }		
 
 	}
 	
@@ -149,90 +169,19 @@ impl Display for Error {
 		// displays each message
 		for error in self.clone().into_iter() {
 				
-			let message_color = match error.level {
-				
-				Level::Warning => Color::Yellow,
-				Level::Error => Color::Red,
-				Level::Note => Color::Blue,
-				
-			};
+			let message_color = error.level.color();
 			 
 			let _ = stdout.queue(SetForegroundColor(message_color));
 			let _ = stdout.queue(SetAttribute(Attribute::Bold));
 			
-			writeln!(f, "\r\n{}", error.description)?;
+			write!(f, "\r\n{}", error.description)?;
 			
 			let _ = stdout.queue(ResetColor);
 			
-			if error.span_maybe.is_some() {
+			if let Some(span) = &error.span_maybe {
 
-				let span = error.span_maybe.clone().unwrap();
-				let string = span.string();
-				let range = span.range(); 
-				let lines = span.start.line .. span.end.line;
-				let mut current_line = 0;
+				span.write_with_color(f, message_color)?;
 
-				let mut should_write_line_indicator = true;
-
-				for (index, character) in string.char_indices() {
-					
-					if character == '\n' || index == 0 { 
-						
-						current_line += 1;
-						should_write_line_indicator = true; 
-					
-					}
-
-					if should_write_line_indicator { 
-						
-						if lines.contains(&current_line) { 
-
-							// writing line number indicator 
-							let _ = stdout.queue(SetForegroundColor(Color::Blue));
-							let _ = stdout.queue(SetAttribute(Attribute::Bold));
-							let _ = stdout.queue(SetAttribute(Attribute::Dim));
-
-							let new_line_maybe = if current_line == 1 { "" } else {"\r\n"};
-
-							write!(f, "{new_line_maybe}{current_line} | ")?;
-
-							if index == 0 {
-
-								if range.contains(&index) {
-
-									let _ = stdout.queue(SetForegroundColor(message_color));
-									let _ = stdout.queue(SetAttribute(Attribute::Bold));
-			
-								} 
-									
-								write!(f, "{character}")?;
-									
-							};
-							
-							let _ = stdout.queue(SetAttribute(Attribute::Reset));
-
-							should_write_line_indicator = false;
-							
-						}
-
-						else { continue; }
-
-					} 
-				
-					if range.contains(&index) {
-
-						let _ = stdout.queue(SetForegroundColor(message_color));
-						let _ = stdout.queue(SetAttribute(Attribute::Bold));
-						
-					} 
-			
-					
-					if character != '\n' && lines.contains(&current_line) { write!(f, "{character}")?; }
-					
-					let _ = stdout.queue(SetAttribute(Attribute::Reset));
-										
-				}
-		
 			}
 			
 		}
